package com.chelvc.framework.rocketmq.interceptor;

import java.util.List;

import com.chelvc.framework.rocketmq.context.RocketMQContextHolder;
import com.chelvc.framework.rocketmq.model.MessageContext;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.util.CollectionUtils;

/**
 * 会话消息监听器接口
 *
 * @author Woody
 * @date 2023/5/18
 */
public interface SessionRocketMQListener<T> extends RocketMQListener<T> {
    /**
     * 获取消息批量消费数量
     *
     * @return 消息数量
     */
    default int getBatchConsumeSize() {
        return 1;
    }

    /**
     * 批量处理消息上下文信息
     *
     * @param contexts 消息上下文对象列表
     */
    default void onMessageContexts(List<MessageContext<T>> contexts) {
        if (!CollectionUtils.isEmpty(contexts)) {
            contexts.forEach(context -> RocketMQContextHolder.consumeMessageContext(context, this::onMessage));
        }
    }
}
